@@ -38,9 +38,10 @@ def patch_everything(mocker):
     """
     Patches every attribute of an object.
     """
-    def patch_everything(item):
-        for attribute in Utils.patchable_attributes(item):
-            mocker.patch.object(item, attribute)
+    def patch_everything(item, autospec=True, excludes=None, includes=None):
+        for attribute in Utils.patchable_attributes(item, excludes=excludes,
+                                                    includes=includes):
+            mocker.patch.object(item, attribute, autospec=autospec)
     return patch_everything
 
 
